@@ -3,8 +3,8 @@
 .. autosummary::
    :toctree: .
 
-   READOUT_TYPES
+   readoutS
    READOUT_PLATFORMS
 """
 
-from ._core import READOUT_PLATFORMS, READOUT_TYPES  # noqa
+from ._core import READOUT_PLATFORMS, readoutS  # noqa
