@@ -1,4 +1,4 @@
 from typing import Literal  # noqa
 
-READOUT_TYPES = Literal["scRNA-seq", "RNA-seq", "flow-cytometry", "image"]
+readoutS = Literal["scRNA-seq", "RNA-seq", "flow-cytometry", "image"]
 READOUT_PLATFORMS = Literal["Chromium (10x)", "Visium (10x)"]
